function [A, fz] = calculate_derivatives(f,v)
% [A fz] = calculate_derivatives(f,v)
%
%     calculates the derivatives of a vector function f(x) at the point x = v.
%
%     f is the function handle
%     v is the input vector
%
%  Output:
%     A is the array of partial derivatives a(i,j) = partial f(i) / partial v(j)
%     fz is the vector returned by fz = f(v)

%  Written by: John S. Loomis
%  Revised:  6 Feb 2003   

fz = feval(f,v);
nv = length(v);
delta = 1e-5;
for j=1:nv
    vold = v(j);
    v(j) = vold+delta;
    fp = feval(f,v);
    v(j) = vold-delta;
    fn = feval(f,v);
    A(:,j)=(fp-fn)/(2*delta);
    v(j)=vold;
end
    